# Filters added to this controller apply to all controllers in the application.
# Likewise, all the methods added will be available for all controllers.

class ApplicationController < ActionController::Base
  # Pick a unique cookie name to distinguish our session data from others'
  session :session_key => '_DBSWEB_session_id'

	# 여기에 선언하면 전체 컨트롤러에 영향을 미친다. 단 signin 액션만 제외하는것을 말한다.
  before_filter :check_authentication, :except => [:signin]

  def check_authentication
    unless session[:admin]
        session[:intended_action] = action_name
        session[:intended_controller] = controller_name
		# user 컨트롤러의 signin 액션을 부르는 것인데, 로그인을 위한 템플릿 페이지는
		# app/view/user/signin.rhtml 을 이다. 실제 submit 이후에는 본 application 컨트롤서의
		# signin 메소드를 호출하게 된다. (application 컨트롤러는 전 컨트롤러에 속한것과 같음.
        redirect_to :action => "signin", :controller => "sign"
    end
  end

  def signin
    if request.post?
		# Admin.autheticate() 는 app/model/admin.rb 에 지정되어 있다.
      user_id = Admin.authenticate(params[:userid], params[:password])
      if user_id != nil
        session[:admin] = user_id
		# 네비게이션중에 어떤 컨트롤러에서 인증을 요구 받았을 경우 되돌가는 컨트롤러와 액션을 지정한다.
        redirect_to :action => session[:intended_action],
                    :controller => session[:intended_controller]
      else
		# 비밀번호가 틀렸거나, id 가 입력되지 않은 경우
        flash[:notice] = 'Invalid userid or password.'
		# 로그인후에 어느 컨트롤러의 액션을 기본으로 갈것인가를 지정한다.
        redirect_to :action => "signin"
      end
    end
  end

  def signout
    session[:admin] = nil
	# 로그아웃하면, 다시 로그인화면으로 돌아가는 것을 지정한다.
	# 필요에 따라서 주메뉴 화면으로 보낼수 있다.
    redirect_to :action => "signin", :controller => "sign"
  end

  def data_dir
	"/backup/"
  end
end
