/**
 * @file misclib.h
 * @brief Support Functions Library Header
 */

/*
 * Support Functions Library Header
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef	MISCLIB_H
#define	MISCLIB_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "log.h"
#include <sys/socket.h>
#include <arpa/inet.h>
#include <stdlib.h>

#define ARRAY_SIZE(x)	sizeof(x) / sizeof((x)[0])
#define	FREE(pointer)	do { free(pointer); (pointer) = NULL; } while(0)

#ifdef ENABLE_DEBUG
#define ASSERT(expression) \
    if(!(expression)) \
    { \
	Log(ERROR, "ASSERTION IN '%s': '%s' is NOT true\n", \
		__func__, #expression); \
	abort(); \
    } 
#else 
#define ASSERT(expression)  (void) 0
#endif

int Accept(int fd, struct sockaddr *sa, socklen_t *salenptr);
int daemonize(void);
int socket_listen(int port);
int Connect(const char *host, const char *port, int timeout);
ssize_t writen(int connfd, const char *buf, size_t len);
ssize_t readn(int fd, void *vptr, size_t n);

#endif
