/**
 * @file core.h
 * @brief Core (Frontend)
 */

/*
 * Core (Frontend)
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef CORE_H
#define CORE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <inttypes.h>

#include "types.h"
#include "core_backup.h"

/* 
 * 작업 종류
 */
#define BACKUP	   0
#define RESTORE	   1
#define DELETE     2

/* 
 * 옵션 플래그
 */
#define INCREMENTAL          (1 << 0)   
#define COMPRESS             (1 << 1)
#define LOCAL_COPY           (1 << 2)   /**< 로컬 복사본 생성 */
#define TIME_LIMIT           (1 << 3)   /**< 시간 제한 */
#define OVERWRITE            (1 << 4)   /**< 원본 덮어 쓰기 */
#define IGNORE_LOCK_FILE     (1 << 5)   /**< 잠긴 파일 무시 */
#define LOCAL_NOCOMPRESS     (1 << 6)   /**< 로컬 복사본은 압축하지 않음 */
#define DIFFERENTIAL         (1 << 7)  
#define REMOVE_LOCAL_COPY    (1 << 8)   /**< 로컬 복사본 삭제 */

/*
 * 옵션 체크 매크로
 */
#define IS_INCREMENTAL(x)        ((x) & INCREMENTAL)
#define IS_COMPRESS(x)	         ((x) & COMPRESS)
#define IS_LOCAL_COPY(x)         ((x) & LOCAL_COPY)
#define IS_TIME_LIMIT(x)         ((x) & TIME_LIMIT)
#define IS_OVERWRITE(x)          ((x) & OVERWRITE)
#define IS_IGNORE_LOCK_FILE(x)   ((x) & IGNORE_LOCK_FILE)
#define IS_LOCAL_NOCOMPRESS(x)   ((x) & LOCAL_NOCOMPRESS)      
#define IS_DIFFERENTIAL(x)       ((x) & DIFFERENTIAL)
#define IS_REMOVE_LOCAL_COPY(x)  ((x) & REMOVE_LOCAL_COPY)

/**
 * BK 쓰레드 헤더 구조체
 */
#define BK_HEADER_SIZE    12
typedef struct
{
    uint32_t type;   /**< 작업 타입 */
    REGNO regno;     /**< 등록번호 */
} BK_Header;

/* DBS Core Main */
void *core(void *arg);

/* BK 쓰레드 헤더 생성 */
void create_bk_header(void *ptr, REGNO regno, int type);

/* 백업 쓰레드 헤더 바이트오더 변환 (네트웍 -> 호스트) */
void bk_ntoh(BK_Header *bk);

/* 네트웍으로 수신한 패킷에서 BK 헤더 파싱 */
void parse_bk_header(BK_Header *bk, void *packet);

/* CORE 쓰레드로 PXE destination host 설정 */
int set_dst_host(PXE *pxe, unsigned char *ip);

#endif
