/**
 * @file core_backup.h
 * @brief Backup Core (Backend)
 */

/*
 * Backup Core (Backend)
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef CORE_BACKUP_H
#define CORE_BACKUP_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <inttypes.h>

#include <pxe.h>
#include "types.h"
#include "../lib/slib.h"

/*
 * 백업 명령어
 */
#define BACKUP_OPEN   0
#define BACKUP_START  1
#define BACKUP_DATA   2
#define BACKUP_END    3
#define BACKUP_ERROR  4

/**
 * 백업 모듈 헤더 구조체
 */
#define BACKUP_HEADER_SIZE    28    
typedef struct
{
    uint8_t ip[4];     /**< 대상 IP */
    int32_t cmd;       /**< 명령어 (OPEN/START/DATA/END/ERROR) */
    TIME ltime;        /**< 제한시간 (TIME_LIMIT 옵션 설정해야 작동함) */
    TIME mtime;        /**< 인크리멘털 기준시간 (INCREMENTAL 옵션 설정해야 작동함) */
    int32_t options;   /**< 옵션 플래그 */
    int32_t fd;        /**< 마스터측 백업 파일 디스크립터 */
    uint32_t len;      /**< 데이터 길이 */
} BackupHeader;

/* 백업모듈 스위치보드 */
int backup_cmd(PXE *pxe, REGNO regno, void *data, void *sql, void **err);

/* 백업모듈 패킷 생성 */
size_t create_backup_packet(void **ptr, REGNO regno,
	BackupHeader *header, void *data, unsigned int len);

/* Peer host에 에러메세지 전송 / 로컬호스트에 로그 기록 */
void ret_backup_error(PXE *pxe, REGNO regno, const BackupHeader *header, 
	const char *format, ...);

/* 네트웍으로 수신한 패킷에서 백업모듈 헤더 파싱 */
void parse_backup_header(BackupHeader *hdr, void *data);

#endif
