/**
 * @file core_delete.h
 * @brief Delete Core (Backend)
 */

/*
 * Delete Core (Backend)
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef CORE_DELETE_H
#define CORE_DELETE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <pxe.h>
#include "types.h"
#include "../lib/slib.h"

/*
 * 삭제 명령어
 */
#define DELETE_OPEN      0
#define DELETE_START     1
#define DELETE_END       2
#define DELETE_ERROR     3

/**
 * 삭제모듈 헤더 구조체
 */
#define DELETE_HEADER_SIZE    24
typedef struct
{
    REGNO bk_sid;      /**< 대상 백업 등록번호 */
    uint8_t ip[4];     /**< 대상 IP */
    int32_t cmd;       /**< 명령어 (START/END/ERROR) */
    int32_t options;   /**< 옵션 플래그 */
    uint32_t len;      /**< 데이터 길이 */
} DeleteHeader;

/**
 * 삭제 메인쓰레드 인자 구조체
 */
typedef struct
{
    REGNO regno;             /**< 등록번호 */
    DeleteHeader header;     /**< 삭제모듈 헤더 */
    unsigned char data[1];   /**< 사용자 데이터 */
} DEL_ARG;

#ifdef HAVE_LIBMYSQLCLIENT
/* 백업 데이터 삭제 */
int delete_backup_data(sql_t *sql, REGNO regno, void **err);
#endif

/* 삭제모듈 패킷 생성 */
size_t create_delete_packet(void **ptr, REGNO regno, 
	DeleteHeader *header, void *data, unsigned int len);

/* 네트웍으로 수신한 패킷에서 삭제모듈 헤더 파싱 */
void parse_delete_header(DeleteHeader *hdr, void *data);

/* 삭제모듈 스위치보드 */
int delete_cmd(PXE *pxe, REGNO regno, void *data, void *sql, void **msg);

#endif
