/**
 * @file core_restore.h
 * @brief Restore Core (Backend)
 */

/*
 * Restore Core (Backend)
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef CORE_RESTORE_H
#define CORE_RESTORE_H

#include <inttypes.h>

#include "types.h"
#include "core_backup.h"

/*
 * 복구 명령어
 */
#define RESTORE_OPEN   0
#define RESTORE_START  1
#define RESTORE_DATA   2
#define RESTORE_END    3
#define RESTORE_ERROR  4

/**
 * 복구모듈 헤더 구조체
 */
#define RESTORE_HEADER_SIZE    28
typedef struct
{
    REGNO bk_sid;      /**< 대상 백업 등록번호 */
    uint8_t ip[4];     /**< 대상 IP */
    int32_t cmd;       /**< 명령어 (OPEN/START/DATA/END/ERROR) */
    TIME ltime;        /**< 제한시간 (TIME_LIMIT 옵션 설정해야 작동함) */
    int32_t options;   /**< 옵션 플래그 */
    uint32_t len;      /**< 데이터 길이 */
} RestoreHeader;

/* 복구모듈 스위치보드 */
int restore_cmd(PXE *pxe, REGNO regno, void *data, void *sql, void **msg);

/* 복구모듈 헤더 바이트오더 변환 (네트웍 -> 호스트) */
void restore_ntoh(RestoreHeader *hdr);

/* 복구모듈 패킷 생성 */
size_t create_restore_packet(void **ptr, REGNO regno, 
	RestoreHeader *header, void *data, unsigned int len);

/* Peer host에 에러메세지 전송 / 로컬호스트에 로그 기록 */
void ret_restore_error(PXE *pxe, REGNO regno, const RestoreHeader *header, 
	const char *format, ...);

/* 백업모듈 헤더 바이트오더 변환 (네트웍 -> 호스트) */
void backup_ntoh(BackupHeader *hdr);

/* 네트웍으로 수신한 패킷에서 복구모듈 헤더 파싱 */
void parse_restore_header(RestoreHeader *hdr, void *data);

#endif
