/**
 * @file db_interface.h
 * @brief DBMS Interface
 */

/*
 * DBMS Interface
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef DB_INTERFACE_H
#define DB_INTERFACE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <inttypes.h>

#include <pxe.h>
#include <libtar.h>
#include "types.h"
#include "../lib/slib.h"

/*
 * 처리 결과 
 */
#define WAIT_STAT	'W'
#define SCANNING_STAT   'S'
#define PENDING_STAT    'P'
#define RUN_STAT	'R'
#define DONE_STAT	'D'
#define FAIL_STAT	'F'
#define ERROR_STAT	'E'
#define CANCEL_STAT     'C'

/*
 * 작업 타입
 */
#define BACKUP_TYPE	"B"
#define RESTORE_TYPE	"R"
#define DELETE_TYPE	"D"

/**
 * DI 쓰레드 헤더 구조체 (메모리 수동정렬 필요) 
 */
typedef struct
{
    REGNO regno;     /**< 등록번호 */
    uint32_t status; /**< 처리결과 */
    uint32_t len;    /**< 메세지 길이 */
} DI_Header;

/* DBMS 인터페이스 쓰레드 메인 */
void *db_interface(void *arg);

/* DI 쓰레드에 처리결과 통보 */
void report_result(REGNO regno, unsigned char status, const char *format, ...);

/* 백업파일 상세정보를 DB에 기록 */
void insert_backup_record(sql_t *sql, REGNO regno, const char *filename, 
	int size, long long mtime, unsigned char type, off_t offset);

/* DBMS 접속해서 SQL 핸들러 생성 */
int dbms_connect(sql_t *sql, void **msg);

/* 백업 당시 압축을 했었는지 확인 */
int is_compressed(sql_t *sql, REGNO regno, void **msg);

/* 백업 대상 에이전트의 이름을 반환한다. */
char *
get_agent_name(sql_t *sql, REGNO regno);

#endif
