/**
 * @file support.h
 * @brief Support Functions
 */

/*
 * Support Functions
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef SUPPORT_H
#define SUPPORT_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <arpa/inet.h>
#include <inttypes.h>

#include "types.h"

/* 
 * uint64_t 바이트오더 변환 메크로 
 */
#ifdef WORDS_BIGENDIAN
#define htonll(x)  (x)
#define ntohll(x)  (x)
#else
#define htonll(x)  ((((uint64_t) htonl((x))) << 32) + htonl((x) >> 32))
#define ntohll(x)  ((((uint64_t) ntohl((x))) << 32) + ntohl((x) >> 32))
#endif

/* 문자열로 된 IP를 정수형으로 변환 */
int convert_ip_to_int(const char *ip, unsigned char *buf);

/* 정수형으로 된 IP를 문자열로 변환 */
char *convert_ip_to_str(const unsigned char *ip, 
	char *buf, size_t len);

/* 특정 문자열로 된 시간을 epoch time으로 변환 */
int convert_time_to_epoch(const char *str, const char *format, time_t *tm);

/* 동적 메모리에 문자열 복사 */
char *dup_str(const char *format, ...);

/* 지정된 제한시간이 지났는지 체크 */
int check_timeout(TIME timeout);

/* 기존 문자열에 새로운 문자열 추가 */
int str_append(char **ptr, const char *str);

/* 문자열안에 어떤 문자가 중복되서 나올경우 한개로 줄여주는 코드 */
int trim_duplicate(char *string, char c);

/* 문자열의 앞에 존재하는 공백을 제거 */
void trim_post_space(char *str);

/* 시스템 인코딩에서 UTF-8로 문자열 변환 (동적 메모리 생성) */
int encode_str_to_utf8(const char *str, char **ptr);

/* UTF-8에서 시스템 인코딩으로 문자열 변환 (동적 메모리 생성) */
int decode_str_from_utf8(const char *str, char **ptr);

/* 문자열로 된 시간을 Unix Timestamp로 변환 */
time_t get_tm(const char *str, const char *format);

/* 대상 문자열에서 \a search 문자열을 찾아서 모두 \a replace 문자열로 치환 */
int str_replace(const char *in, char **out, const char *search, 
	const char *replace);

#endif
