/**
 * @file tar_frontend.h
 * @brief Frontend of TAR library
 */

/*
 * Frontend of TAR library
 *
 * Copyright 2007 Samjung Data Service, Inc.  All rights reserved.
 * 김기태 (superkkt@sds.co.kr)
 */

#ifndef LTAR_H
#define LTAR_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <pxe.h>
#include "types.h"
#include "core_backup.h"
#include "core_restore.h"

/**
 * TAR 리스트 내부 버퍼 사이즈 (반드시 TAR_BLOCK_SIZE의 배수여야 함) 
 */
#define INTERNAL_BUF	(16 * 1024)

/**
 * USTAR 매직 스트링
 */
#define USTAR_MAGIC "ustar"

/**
 * DBS 전용 매직 스트링
 */
#define DBS_MAGIC   "DBSHD"

/**
 * 매직 스트링 길이
 */
#define MAGIC_LEN   5

/**
 * 백업작업 정보 구조체 
 */
typedef struct
{
    REGNO regno;            /**< 등록번호 */
    PXEThread src;          /**< Source Thread */
    BackupHeader header;    /**< 백업모듈 헤더 */
    size_t len;             /**< 데이터 길이 */
    char data[1];           /**< 데이터 */
} BackupInfo;

/**
 * 복구작업 정보 구조체 
 */
typedef struct
{
    REGNO regno;            /**< 등록번호 */
    PXEThread src;          /**< Source Thread */
    RestoreHeader header;   /**< 복구모듈 헤더 */
    size_t len;             /**< 데이터 길이 */
    char data[1];           /**< 데이터 */
} RestoreInfo;

/* TAR 리스트 초기화 */
int init_tar_list(void);

/* 백업용 Libtar 쓰레드 */
void *ltar_backup(void *arg);

/* 백업정보 구조체 생성 */
size_t create_ltar_backup_info(void **ptr, REGNO regno, PXEThread src,
	BackupHeader *hdr, const void *buf, size_t len);

/* 복구용 Libtar 쓰레드 */
void *ltar_restore(void *arg);

/* 복구정보 구조체 생성 */
size_t create_ltar_restore_info(void **ptr, REGNO regno,
	RestoreHeader *hdr, const void *buf, size_t len);

#ifdef HAVE_LIBMYSQLCLIENT
/* TAR 헤더 기록 */
void write_tar_header(sql_t *sql, REGNO regno, char *packet, PXELength len, 
	off_t offset);
#endif

#endif
